"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mobileGetUiMode = exports.mobileSetUiMode = void 0;
const utils_1 = require("../utils");
const RESPONSE_PATTERN = /:\s+(\w+)/;
/**
 * Set the Ui appearance.
 *
 * @since Android 10
 * @this {import('../driver').AndroidDriver}
 * @property {import('./types').SetUiModeOpts}
 * @returns {Promise<void>}
 */
async function mobileSetUiMode(opts) {
    const { mode, value } = (0, utils_1.requireArgs)(['mode', 'value'], opts);
    await this.adb.shell(['cmd', 'uimode', mode, value]);
}
exports.mobileSetUiMode = mobileSetUiMode;
/**
 * Get the Ui appearance.
 *
 * @since Android 10
 * @this {import('../driver').AndroidDriver}
 * @property {import('./types').GetUiModeOpts}
 * @returns {Promise<string>} The actual state for the queried UI mode,
 * for example 'yes' or 'no'
 */
async function mobileGetUiMode(opts) {
    const { mode } = (0, utils_1.requireArgs)(['mode'], opts);
    const response = await this.adb.shell(['cmd', 'uimode', mode]);
    // response looks like 'Night mode: no'
    const match = RESPONSE_PATTERN.exec(response);
    if (!match) {
        throw new Error(`Cannot parse the command response: ${response}`);
    }
    return match[1];
}
exports.mobileGetUiMode = mobileGetUiMode;
//# sourceMappingURL=appearance.js.map